# IQS324 Arduino Example Code

## Introduction

This Arduino example code demonstrates how to set up and use the IQS324 Hall encoder
using I2C.
The Arduino can be configured to emulate a mouse scroll wheel using the
[*Mouse*](https://www.arduino.cc/reference/en/language/functions/usb/mouse/)
library by providing mouse scroll commands over HID.
This example code is specifically aimed at the IQS324 Evaluation Kit
(PCB number _AZP1400A1_).

The following external Arduino libraries are needed to compile the example pack:

* [*Mouse*](https://www.arduino.cc/reference/en/language/functions/usb/mouse/)

This requires an Arduino board that supports HID over USB and 3.3 V logic, such as
[Sparkfun's Pro Micro (3.3V, 8 MHz)](https://learn.sparkfun.com/tutorials/pro-micro--fio-v3-hookup-guide/hardware-overview-pro-micro).

## Arduino Code Configuration

The behaviour and pin assignments of the Arduino code can be configured with the
`#define` settings at the start of `iqs324-example-code.ino`.

Change the following pin assignments and parameters to suit your hardware:

```c
/*** Defines ***/
#define DEMO_IQS324_ADDR 0x54
#define DEMO_IQS324_POWER_PIN 4
#define DEMO_IQS324_RDY_PIN 7

/* UI Selection */
#define DEMO_HID_ON 1 // Turn on HID and give mouse scroll commands over USB.
```

* `DEMO_IQS324_POWER_PIN` can be used to power the IQS324 directly from
  an Arduino GPIO.
  This parameter sets which pin to use.
  This is an optional setting and can be removed if the IQS324 is powered
  from the VCC pin or an external power supply.
* `DEMO_IQS324_RDY_PIN` sets the pin assignment for the IQS324 ready pin.
  This must support external interrupts.
  On the SparkFun Pro Micro, pins 0, 1, 2, 3, and 7 support interrupts.
* `DEMO_HID_ON` sends mouse scroll events over USB HID to the computer to
  emulate a mouse wheel.
  Enabling this requires the
  [Mouse](https://www.arduino.cc/reference/en/language/functions/usb/mouse/)
  library.

NOTE: Please note that powering an IQS device directly from a GPIO is _generally_ not
recommended.
The `DEMO_IQS324_POWER_PIN` can be used as an
enable input to a voltage regulator.

## Example Code Flow Diagram

![](docs/images/flow-diagram.svg)

## SparkFun Board Library Installation

To use the SparkFun Pro Micro, the SparkFun Board Library must be installed
in the Arduino IDE.

Add the SparkFun Board Library by opening Preferences (*File* > *Preferences*),
and paste the following URL into the "Additional Board Manager URLs" text box.

```
https://raw.githubusercontent.com/sparkfun/Arduino_Boards/master/IDE_Board_Manager/package_sparkfun_index.json
```

![](docs/images/arduino-board-manager-link.png)

Click "OK".
Then open the Board Manager under **Tools** > **Board** > **Boards Manager...**.

![](docs/images/board-manager.png)

Search for "SparkFun", and install "SparkFun AVR Boards by SparkFun".

![](docs/images/board-manager-sparkfun.png)

You can now select the "SparkFun Pro Micro" in the Board selection menu.

![](docs/images/select-pro-micro.png)

Also be sure to select the "3.3 V, 8 MHz" version under *Tools* > *Processor*.

![](docs/images/select-3v3.png)

Source:
[Pro Micro Hookup Guide](https://learn.sparkfun.com/tutorials/pro-micro--fio-v3-hookup-guide)

## Install Mouse Library

To install the Mouse library for the example code, open the
Library Manager by navigating to *Tools* > *Manage Libraries...*.

![](docs/images/library-manager.png)

Search for "mouse", and install "*Mouse* by *Arduino*".

![](docs/images/mouse.png)

## Serial Communication and Interface

The example code provides verbose serial feedback to aid in the
demonstration of start-up and operational functions.

![](docs/images/iqs324_successful_serial.png)
